package com.bonus.material.settlement.mapper;

import java.util.List;
import com.bonus.material.settlement.domain.SltProjectMonth;

/**
 * 月结算任务索引Mapper接口
 * 
 * @author xsheng
 * @date 2024-10-16
 */
public interface SltProjectMonthMapper {
    /**
     * 查询月结算任务索引
     * 
     * @param id 月结算任务索引主键
     * @return 月结算任务索引
     */
    public SltProjectMonth selectSltProjectMonthById(Long id);

    /**
     * 查询月结算任务索引列表
     * 
     * @param sltProjectMonth 月结算任务索引
     * @return 月结算任务索引集合
     */
    public List<SltProjectMonth> selectSltProjectMonthList(SltProjectMonth sltProjectMonth);

    /**
     * 新增月结算任务索引
     * 
     * @param sltProjectMonth 月结算任务索引
     * @return 结果
     */
    public int insertSltProjectMonth(SltProjectMonth sltProjectMonth);

    /**
     * 修改月结算任务索引
     * 
     * @param sltProjectMonth 月结算任务索引
     * @return 结果
     */
    public int updateSltProjectMonth(SltProjectMonth sltProjectMonth);

    /**
     * 删除月结算任务索引
     * 
     * @param id 月结算任务索引主键
     * @return 结果
     */
    public int deleteSltProjectMonthById(Long id);

    /**
     * 批量删除月结算任务索引
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSltProjectMonthByIds(Long[] ids);
}
