package com.bonus.material.settlement.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.settlement.domain.SltProjectMonth;
import com.bonus.material.settlement.service.ISltProjectMonthService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 月结算任务索引Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "月结算任务索引接口")
@RestController
@RequestMapping("/slt_project_month")
public class SltProjectMonthController extends BaseController {
    @Autowired
    private ISltProjectMonthService sltProjectMonthService;

    /**
     * 查询月结算任务索引列表
     */
    @ApiOperation(value = "查询月结算任务索引列表")
    @RequiresPermissions("settlement:month:list")
    @GetMapping("/list")
    public TableDataInfo list(SltProjectMonth sltProjectMonth) {
        startPage();
        List<SltProjectMonth> list = sltProjectMonthService.selectSltProjectMonthList(sltProjectMonth);
        return getDataTable(list);
    }

    /**
     * 导出月结算任务索引列表
     */
    @ApiOperation(value = "导出月结算任务索引列表")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:month:export")
    @SysLog(title = "月结算任务索引", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出月结算任务索引")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SltProjectMonth sltProjectMonth) {
        List<SltProjectMonth> list = sltProjectMonthService.selectSltProjectMonthList(sltProjectMonth);
        ExcelUtil<SltProjectMonth> util = new ExcelUtil<SltProjectMonth>(SltProjectMonth.class);
        util.exportExcel(response, list, "月结算任务索引数据");
    }

    /**
     * 获取月结算任务索引详细信息
     */
    @ApiOperation(value = "获取月结算任务索引详细信息")
    @RequiresPermissions("settlement:month:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(sltProjectMonthService.selectSltProjectMonthById(id));
    }

    /**
     * 新增月结算任务索引
     */
    @ApiOperation(value = "新增月结算任务索引")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:month:add")
    @SysLog(title = "月结算任务索引", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增月结算任务索引")
    @PostMapping
    public AjaxResult add(@RequestBody SltProjectMonth sltProjectMonth) {
        try {
            return toAjax(sltProjectMonthService.insertSltProjectMonth(sltProjectMonth));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改月结算任务索引
     */
    @ApiOperation(value = "修改月结算任务索引")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:month:edit")
    @SysLog(title = "月结算任务索引", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改月结算任务索引")
    @PutMapping
    public AjaxResult edit(@RequestBody SltProjectMonth sltProjectMonth) {
        try {
            return toAjax(sltProjectMonthService.updateSltProjectMonth(sltProjectMonth));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除月结算任务索引
     */
    @ApiOperation(value = "删除月结算任务索引")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:month:remove")
    @SysLog(title = "月结算任务索引", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除月结算任务索引")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(sltProjectMonthService.deleteSltProjectMonthByIds(ids));
    }
}
